<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Support\Assets
 * @copyright   Copyright (c) 2022, WeCodeArt Framework
 * @since 		5.4.5
 * @version		5.4.5
 */

namespace WeCodeArt\Support;

defined( 'ABSPATH' ) || exit;

use WeCodeArt\Singleton;
use WeCodeArt\Integration;
use WeCodeArt\Conditional\Traits\No_Conditionals;
use function WeCodeArt\Functions\get_prop;

/**
 * The Fonts object.
 */
final class Locale implements Integration {

	use Singleton;
	use No_Conditionals;

	/**
	 * Register hooks
	 */
	public function register_hooks() {
		\add_action( 'after_setup_theme', [ $this, 'translations' ] );
	}

	/**
	 * Load Translations
	 *
	 * @since	5.4.5
	 * @version 5.4.5
	 *
	 * @return 	void
	 */
	public function translations() {
		$paths 	= wecodeart_config( 'paths' );
		$lang 	= wecodeart_config( 'directories' )['languages'];

		// Loads wp-content/languages/themes/wecodeart-it_IT.mo.
		load_theme_textdomain( 'wecodeart', trailingslashit( WP_LANG_DIR ) . 'themes' );

		// Loads wp-content/themes/child-theme-name/languages/it_IT.mo.
		load_theme_textdomain( 'wecodeart', $paths['child'] . $lang );

		// Loads wp-content/themes/wecodeart/languages/it_IT.mo.
		load_theme_textdomain( 'wecodeart', $paths['directory'] . $lang );
	}
}